@@ -24,18 +24,15 @@ from aiohomekit.crypto.chacha20poly1305 import (
 )
 from aiohomekit.exceptions import (
     AccessoryDisconnectedError,
-    AccessoryNotFoundError,
     AuthenticationError,
     ConnectionError,
     HomeKitException,
-    HttpErrorResponse,
     TimeoutError,
 )
 from aiohomekit.http import HttpContentTypes
 from aiohomekit.http.response import HttpResponse
 from aiohomekit.protocol import get_session_keys
 from aiohomekit.protocol.tlv import TLV
-from aiohomekit.zeroconf import async_find_device_ip_and_port
 
 logger = logging.getLogger(__name__)
 
@@ -73,7 +70,7 @@ class InsecureHomeKitProtocol(asyncio.Protocol):
         self.result_cbs.append(result)
 
         try:
-            return await asyncio.wait_for(result, 30)
+            return await asyncio.wait_for(result, 10)
         except asyncio.TimeoutError:
             self.transport.write_eof()
             self.transport.close()
@@ -262,9 +259,7 @@ class HomeKitConnection:
 
     async def put_json(self, target, body):
         response = await self.put(
-            target,
-            json.dumps(body).encode("utf-8"),
-            content_type=HttpContentTypes.JSON,
+            target, json.dumps(body).encode("utf-8"), content_type=HttpContentTypes.TLV,
         )
 
         if response.code == 204:
@@ -326,13 +321,9 @@ class HomeKitConnection:
         return parsed
 
     async def post_tlv(self, target, body, expected=None):
-        try:
-            response = await self.post(
-                target, TLV.encode_list(body), content_type=HttpContentTypes.TLV,
-            )
-        except HttpErrorResponse as e:
-            self.transport.close()
-            response = e.response
+        response = await self.post(
+            target, TLV.encode_list(body), content_type=HttpContentTypes.TLV,
+        )
         body = TLV.decode_bytes(response.body, expected=expected)
         return body
 
@@ -348,11 +339,6 @@ class HomeKitConnection:
         :param headers: a list of (header, value) tuples (optional)
         :param body: The body of the request (optional)
         """
-        if not self.protocol:
-            raise AccessoryDisconnectedError(
-                "Connection lost before request could be sent"
-            )
-
         buffer = []
         buffer.append(
             "{method} {target} HTTP/1.1".format(method=method.upper(), target=target,)
@@ -382,19 +368,7 @@ class HomeKitConnection:
         # https://github.com/jlusiardi/homekit_python/issues/12
         # https://github.com/jlusiardi/homekit_python/issues/16
 
-        logger.debug("%s: raw request: %r", self.host, request_bytes)
-        resp = await self.protocol.send_bytes(request_bytes)
-
-        if resp.code >= 400 and resp.code <= 499:
-            logger.debug(f"Got HTTP error {resp.code} for {method} against {target}")
-            raise HttpErrorResponse(
-                f"Got HTTP error {resp.code} for {method} against {target}",
-                response=resp,
-            )
-
-        logger.debug("%s: raw response: %r", self.host, resp.body)
-
-        return resp
+        return await self.protocol.send_bytes(request_bytes)
 
     async def close(self):
         """
@@ -514,13 +488,6 @@ class SecureHomeKitConnection(HomeKitConnection):
     async def _connect_once(self):
         self.is_secure = False
 
-        try:
-            self.host, self.port = await async_find_device_ip_and_port(
-                self.pairing_data["AccessoryPairingID"]
-            )
-        except AccessoryNotFoundError:
-            pass
-
         await super()._connect_once()
 
         state_machine = get_session_keys(self.pairing_data)
