@@ -70,7 +70,7 @@ class Characteristic(ToDictMixin):
         self.minStep = self._get_configuration(kwargs, "min_step", None)
         self.maxLen = 64
         self.maxDataLen = 2097152
-        self.valid_values = None
+        self.valid_values = self._get_configuration(kwargs, "valid_values", None)
         self.valid_values_range = None
 
         self.value = None
@@ -109,6 +109,13 @@ class Characteristic(ToDictMixin):
             return default
         return characteristics[self.type][key]
 
+    @property
+    def type_name(self):
+        try:
+            return CharacteristicsTypes.get_short(self.type)
+        except KeyError:
+            return None
+
     def set_events(self, new_val):
         self.ev = new_val
 
